@@ -4,14 +4,20 @@ function (betas) {
     if (parameterization %in% c("value", "both")) {
         Y <- as.vector(Xtime %*% betas) + Ztime.b
         Ys <- as.vector(Xs %*% betas) + Zsb
-        eta.t <- eta.tw + alpha * Y
-        eta.s <- alpha * Ys
+        eta.t <- eta.tw + c(WintF.vl %*% alpha) * Y
+        eta.s <- c(Ws.intF.vl %*% alpha) * Ys
     }
     if (parameterization %in% c("slope", "both")) {
         Y.deriv <- as.vector(Xtime.deriv %*% betas[indFixed]) + Ztime.b.deriv
         Ys.deriv <- as.vector(Xs.deriv %*% betas[indFixed]) + Zsb.deriv
-        eta.t <- if (parameterization == "both") eta.t + Dalpha * Y.deriv else eta.tw + Dalpha * Y.deriv
-        eta.s <- if (parameterization == "both") eta.s + Dalpha * Ys.deriv else Dalpha * Ys.deriv
+        eta.t <- if (parameterization == "both") 
+            eta.t + c(WintF.sl %*% Dalpha) * Y.deriv
+        else
+            eta.tw + c(WintF.sl %*% Dalpha) * Y.deriv
+        eta.s <- if (parameterization == "both")
+            eta.s + c(Ws.intF.sl %*% Dalpha) * Ys.deriv 
+        else
+            c(Ws.intF.sl %*% Dalpha) * Ys.deriv
     }
     mu.y <- eta.yx + Ztb
     logNorm <- dnorm(y, mu.y, sigma, TRUE)
