@@ -5,7 +5,10 @@ function (object, type = c("mean", "mode"), postVar = FALSE, ...) {
     type <- match.arg(type)
     if (type == "mean") {
         out <- as.matrix(object$EB$post.b)
-        rownames(out) <- names(object$y$logT)
+        rownames(out) <-  if (!object$CompRisk && !object$LongFormat)
+            names(object$y$logT)
+        else 
+            seq_len(nrow(out))
         if (postVar) {
             n <- nrow(out)
             ncz <- ncol(out)
